@@ -103,7 +103,7 @@ setMethod("sim", signature(object = "glm"),
 #)
 
 setMethod("sim", signature(object = "mer"),
-    function(object, n.sims=100)
+    function(object, n.sims=100, ranef=FALSE)
     {
     # simulate unmodeled coefficients
     fcoef <- fixef(object)
@@ -114,27 +114,30 @@ setMethod("sim", signature(object = "mer"),
     if (length (fcoef) > 0){
       beta.unmodeled[[1]] <- mvrnorm (n.sims, fcoef, V.beta)
       names (beta.unmodeled) <- "fixef"#"unmodeled"
+      coef <- beta.unmodeled
     }
-   # simulate coefficients within groups
-    sc <- attr (VarCorr (object), "sc")  # scale
-    #coef <- ranef (object)
-    #estimate <- ranef(object, postVar=TRUE)
-    coef <- ranef(object, postVar=TRUE)
-    beta.bygroup <- coef
-    n.groupings <- length (coef)
-    for (m in 1:n.groupings){
-      bhat <- as.matrix(coef[[m]]) # to suit the use of mvrnorm
-      vars.m <- attr (coef[[m]], "postVar")
-      K <- dim(vars.m)[1]
-      J <- dim(vars.m)[3]
-      beta.bygroup[[m]] <- array (NA, c(n.sims, J, K))
-      for (j in 1:J){
-        V.beta <- .untriangle(vars.m[,,j])#*sc^2
-        beta.bygroup[[m]][,j,] <- mvrnorm (n.sims, bhat[j,], V.beta)
-      }   
-      dimnames (beta.bygroup[[m]]) <- c (list(NULL), dimnames(bhat))
-    }
-    coef <- c (beta.unmodeled, beta.bygroup)
+    if(ranef){
+      # simulate coefficients within groups
+      sc <- attr (VarCorr (object), "sc")  # scale
+      #coef <- ranef (object)
+      #estimate <- ranef(object, postVar=TRUE)
+      coef <- ranef(object, postVar=TRUE)
+      beta.bygroup <- coef
+      n.groupings <- length (coef)
+      for (m in 1:n.groupings){
+        bhat <- as.matrix(coef[[m]]) # to suit the use of mvrnorm
+        vars.m <- attr (coef[[m]], "postVar")
+        K <- dim(vars.m)[1]
+        J <- dim(vars.m)[3]
+        beta.bygroup[[m]] <- array (NA, c(n.sims, J, K))
+        for (j in 1:J){
+          V.beta <- .untriangle(vars.m[,,j])#*sc^2
+          beta.bygroup[[m]][,j,] <- mvrnorm (n.sims, bhat[j,], V.beta)
+        }   
+        dimnames (beta.bygroup[[m]]) <- c (list(NULL), dimnames(bhat))
+      }
+      coef <- c (beta.unmodeled, beta.bygroup)
+      }
     return (coef)
     }
 )
